aboutsummaryrefslogtreecommitdiff
path: root/include/util.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/util.h')
-rw-r--r--include/util.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/include/util.h b/include/util.h
index 3cba49f0..931ac691 100644
--- a/include/util.h
+++ b/include/util.h
@@ -11,10 +11,11 @@
int wrap(int i, int max);
/**
* Given a string that represents an RGB(A) color, return a uint32_t
* version of the color.
*/
-uint32_t parse_color(const char *color);
+bool parse_color(const char *color, uint32_t *result);
/**
* Given a string that represents a boolean, return the boolean value. This
@@ -11,10 +11,11 @@
int wrap(int i, int max);
/**
- * Given a string that represents an RGB(A) color, return a uint32_t
- * version of the color.
+ * Given a string that represents an RGB(A) color, result will be set to a
+ * uint32_t version of the color, as long as it is valid. If it is invalid,
+ * then false will be returned and result will be untouched.
*/